@@ -16,6 +16,10 @@ def get_a_buffer(size, context=None, buffer=None, offset=None):
         offset = buffer.allocate(size)
     elif offset == "aligned":
         offset = buffer.allocate(size, align=True)
+    elif offset == "packed":
+        offset = buffer.allocate(size, align=False)
+    if isinstance(offset, str):
+        raise ValueError(f'Invalid offset {offset}')
     return buffer, offset
 
 
